@@ -158,11 +158,11 @@ class Nation : RulesetObject() {
         fun addBonusLines(header: String, uniqueMap: UniqueMap) {
             // Note: Using getCityStateBonuses would be nice, but it's bound to a CityStateFunctions instance without even using `this`.
             // Too convoluted to reuse that here - but feel free to refactor that into a static.
-            val boni = uniqueMap.getAllUniques().filterNot { it.isHiddenToUsers() }
-            if (boni.none()) return
+            val bonuses = uniqueMap.getAllUniques().filterNot { it.isHiddenToUsers() }
+            if (bonuses.none()) return
             textList += FormattedLine()
             textList += FormattedLine("{$header:} ")
-            for (unique in boni) {
+            for (unique in bonuses) {
                 textList += FormattedLine(unique, indent = 1)
                 if (unique.isOfType(UniqueType.CityStateUniqueLuxury)) showResources = true
             }
